@@ -279,7 +279,7 @@ $extGeshi = array(
 	'eiffel'		=> array('e'),
 	'erlang'		=> array('erl'),
 	'email'			=> array('eml'),
-	'fortran'		=> array('f', 'for'),
+	'fortran'		=> array('f', 'for', 'f90'),
 	'gettext'		=> array('po', 'pot'),
 	'gml'			=> array('gml'),
 	'gnuplot'		=> array('plt'),
@@ -298,6 +298,7 @@ $extGeshi = array(
 	'perl'			=> array('pl', 'pm'),
 	'php'			=> array('php', 'php3', 'php4', 'php5', 'phps', 'phtml'),
 	'povray'		=> array('pov'),
+	'properties'	=> array('properties'),
 	'providex'		=> array('pvc', 'pvx'),
 	'python'		=> array('py'),
 	'reg'			=> array('reg'),
@@ -314,7 +315,7 @@ $extGeshi = array(
 	'vhdl'			=> array('vhd', 'vhdl'),
 	'vim'			=> array('vim'),
 	'whitespace'	=> array('ws'),
-	'xml'			=> array('xml', 'xsl', 'xsd', 'xib', 'wsdl', 'svg', 'plist'),
+	'xml'			=> array('xml', 'xsl', 'xsd', 'xib', 'wsdl', 'svg', 'plist', 'jmx'),
 	'z80'			=> array('z80'),
 );
 
@@ -359,11 +360,6 @@ if (!$confSuccess) {
 // Make sure that the input locale is set up correctly
 putenv("LANG=".setlocale(LC_ALL, $config->getLocale()));
 
-// assure that a default timezone is set
-if (function_exists('date_default_timezone_get')) {
-	$timezone = @date_default_timezone_get();
-	date_default_timezone_set($timezone);
-}
 $vars['showageinsteadofdate'] = $config->showAgeInsteadOfDate();
 
 // Initialize the version of SVN that is being used by WebSVN internally.
